.. Setup build dependency
.. include:: ../mons/config.py
   :end-line: 0

.. py:currentmodule:: mons.config

Configuration
=============

.. only:: man

   NAME
   ----

   mons - Configuration file


   Synopsis
   --------

`$XDG_CONFIG_HOME/mons/config.yaml`


.. only:: man

   Description
   -----------

.. autodocstr:: Config


.. only:: man

   Options
   -------


.. autoclassmembers:: Config
   :members:
   :skip_docstr: toplevel
